@@ -12,7 +12,7 @@ from lark.exceptions import UnexpectedCharacters, UnexpectedEOF
 def parse_ahb_expression_to_single_requirement_indicator_expressions(ahb_expression: str) -> Tree:
     """
     Parse a given expression as it appears in the AHB with the help of the here defined grammar to a lark tree.
-    The goal is to separate the requirement indicator (i.e. Muss, Soll, Kann, X, O, U) from the condition expression
+    The goal is to separate the requirement indicator (i.e. Muss/M Soll/S Kann/K, X, O, U) from the condition expression
     and also several expression with modal marks if there are more than one.
     Whitespaces are ignored.
 
@@ -29,19 +29,20 @@ def parse_ahb_expression_to_single_requirement_indicator_expressions(ahb_express
     modal_mark_expression: (MODAL_MARK CONDITION_EXPRESSION) -> single_requirement_indicator_expression
     prefix_operator_expression: PREFIX_OPERATOR CONDITION_EXPRESSION -> single_requirement_indicator_expression
     requirement_indicator: PREFIX_OPERATOR | MODAL_MARK
-    PREFIX_OPERATOR: "X" | "O" | "U"
-    MODAL_MARK: "Muss" | "Kann" | "Soll"
+    PREFIX_OPERATOR: "X"i | "O"i | "U"i
+    MODAL_MARK: /M(uss)?|S(oll)?|K(ann)?/i
     // Matches if it looks like a condition expression, but does not yet check if it is a syntactically valid one:
-    CONDITION_EXPRESSION: /[\[\]\(\)U∧O∨X⊻\d\s]+/
+    CONDITION_EXPRESSION: /(?!\BU\B)[\[\]\(\)U∧O∨X⊻\d\s]+/i
     """
-
+    # Regarding the negative lookahead in the condition expression regex see examples https://regex101.com/r/6fFHD4/1
+    # and CTRL+F for "Mus[2]" in the unittest that fails if you remove the lookahead.
     parser = Lark(grammar, start="ahb_expression")
     try:
         parsed_tree = parser.parse(ahb_expression)
     except (UnexpectedEOF, UnexpectedCharacters, TypeError) as eof:
         raise SyntaxError(
             """Please make sure that the ahb_expression starts with a requirement indicator \
-(i.e Muss, Soll, Kann, X, O, U) and the condition expressions consist of only \
+(i.e Muss/M, Soll/S, Kann/K, X, O, U) and the condition expressions consist of only \
 the following characters: [ ] ( ) U ∧ O ∨ X ⊻ and digits."""
         ) from eof
 
