@@ -47,7 +47,7 @@ class TestEvaluatorFactory:
             pytest.param("Muss [2] O [3][902]U[501]", "Muss", True, None),
         ],
     )
-    def test_correct_injection(
+    async def test_correct_injection(
         self,
         inject_content_evaluation_result,
         expression: str,
@@ -57,7 +57,7 @@ class TestEvaluatorFactory:
     ):
         tree = parse_ahb_expression_to_single_requirement_indicator_expressions(ahb_expression=expression)
         assert tree is not None
-        expression_evaluation_result = evaluate_ahb_expression_tree(tree, entered_input="hello")
+        expression_evaluation_result = await evaluate_ahb_expression_tree(tree, entered_input="hello")
         assert (
             expression_evaluation_result.requirement_constraint_evaluation_result.requirement_constraints_fulfilled
             is True
